==> hlw-core-0.0.2-20250815.021856-141-sources.jar: cn/gtmap/hlw/core/model/GxYySqxxKz.java <==
package cn.gtmap.hlw.core.model;

import lombok.Data;

import java.util.List;

/**
 * (GxYySqxxKz)表实体类BO
 *
 * @author makejava
 * @since 2023-05-31 14:14:46
 */
@Data
public class GxYySqxxKz {

    /**
     * 关联sqxx表sqid
     */
    private String sqid;

    /**
     * 创建接口返回proid
     */
    private String proid;

    /**
     * 登记事由（多个以/分隔）
     */
    private String djsy;

    /**
     * 准销证号
     */
    private String zxzh;

    /**
     * ems自动推送状态（0:失败，1：成功）
     */
    private String emstszt;

    /**
     * 解除原因
     */
    private String jcyy;

    /**
     * 是否完全开发(0-否，1-是)
     */
    private String sfwqkf;

    /**
     * 更正登记类型代码
     */
    private String gzdjlxdm;

    /**
     * 更正主体
     */
    private String gzzt;

    /**
     * 更正依据
     */
    private String gzyj;

    /**
     * 更正内容
     */
    private String gznr;

    /**
     * 申请材料提交方式
     */
    private String sqcltjfs;

    /**
     * 项目子编号
     */
    private String xmzbh;

    /**
     * 水电气操作人
     */
    private String sdqczr;

    /**
     * 不处理原因
     */
    private String bclyy;

    /**
     * 违约责任
     */
    private String wyzr;

    /**
     * 监证机关
     */
    private String jzjg;

    /**
     * 是否线上缴税
     */
    private String sfxsjs;

    /**
     * 查询目的（gx_yy_zd_type字典表CXMD）
     */
    private String cxmd;

    /**
     * 是否自动创建 1：是，0：否
     */
    private String sfzdcj;

    /**
     * 是否银行直连1：是，0：否
     */
    private String sfyhzl;

    /**
     * 申请单位唯一标识(代码)
     */
    private String sqdwwybs;

    /**
     * 是否台账展示，1：是（单个、批量第一个），0：否 2转移 3抵押
     */
    private String sftzzs;

    /**
     * 缴款方式 0：不交税费1：税费同缴
     */
    private String jkfs;

    /**
     * 数据来源(1:微信 2:网页 3:APP)
     */
    private String sjly;

    /**
     * 缴费方式（1:线上缴费 2:窗口缴费)
     */
    private String jffs;

    /**
     * 是否税费托管（0否，1是)
     */
    private String sfsftg;

    /**
     * 立案文书编号
     */
    private String lawsbh;

    /**
     * 律师联系电话
     */
    private String lslxdh;

    /**
     * 律师证号
     */
    private String lszh;

    /**
     * 0未查询 1已查询 有结果 2已查询 无结果 3 查询异常
     */
    private String cxzt;

    /**
     * 查询申请人类别（gx_yy_zd_type字典表CXSQRLB）
     */
    private String cxsqrlb;

    /**
     * 查询目的手填
     */
    private String cxmdst;

    /**
     * 是否需要登簿发证 （0：否，1：是）
     */
    private String sfxydbfz;

    /**
     * 公告类型
     */
    private String gglx;

    /**
     * 发布单位
     */
    private String fbdw;

    /**
     * 登记证书形式代码（1：纸质证 2：电子证）
     */
    private String djzsxsdm;

    /**
     * 预审地区代码
     */
    private String ysdqdm;

    /**
     * 集成化办公登记回调标识
     */
    private String djhdbs;

    /**
     * 集成化办公税务回调标识
     */
    private String swhdbs;

    /**
     * 拆迁单位
     */
    private String cqdw;

    /**
     * 是否推送预审 1：是，0：否
     */
    private String sftsys;

    /**
     * 是否市县一体化流程（0：否，1：是）
     */
    private String sfsxythlc;

    /**
     * 是否线下办理（1：是，0：否）
     */
    private String sfxxbl;

    /**
     * 是否完成视频公证（1：是，0：否）
     */
    private String sfwcspgz;

    /**
     * 是否已发送税费短信（1：是，0：否）
     */
    private String sfyfssfdx;

    /**
     * 完税时间
     */
    private String wssj;
    /**
     * 核税时间
     */
    private String hssj;

    /**
     * 赠与合同约定条款
     */
    private String zyhtydtk;

    /**
     * 是否需要云签 0：否 1：是，（整个流程是否需要发起云签）
     */
    private String sfyq;
    /**
     * 智慧中枢受理编号
     */
    private String zhzsslbh;
    /**
     * 证书类型（1：生成证书，2：生成证明，3：只登簿不发证）
     */
    private String zslx;
    /**
     * 用章操作人id
     */
    private List<String> yzczrid;
    /**
     * 是否勾选我已承诺,1：是 0：否
     */
    private String sfgxwycn;
    /**
     * 是否预告 （0：是 1：否）
     */
    private String sfyg;
    /**
     * 登记费免收事项代码
     */
    private String djfmssxdm;
    /**
     * 登记费免收事项名称
     */
    private String djfmssxmc;

    /**
     * 是否带押过户
     */
    private String sfdygh;

    /**
     * 是否无还本续贷款
     */
    private String sfwhbxd;

    /**
     * 是否提供现场服务
     */
    private String sftgxcfw;

    /**
     * 扩展字段json，新增字段都以json方式放该字段里面
     */
    private String kzJson;
    /**
     * 业务小类
     */
    private String ywxl;
    /**
     * 是否整体发证(0：否，1：是)
     */
    private String sfztfz;
    /**
     * 是否跨行抵押
     */
    private String sfkhdy;
}

==> hlw-core-0.0.2-20250828.021836-145-sources.jar: cn/gtmap/hlw/core/model/GxYySqxxKz.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.annotation.TableField;
import lombok.Data;

import java.util.List;

/**
 * (GxYySqxxKz)表实体类BO
 *
 * @author makejava
 * @since 2023-05-31 14:14:46
 */
@Data
public class GxYySqxxKz {

    /**
     * 关联sqxx表sqid
     */
    private String sqid;

    /**
     * 创建接口返回proid
     */
    private String proid;

    /**
     * 登记事由（多个以/分隔）
     */
    private String djsy;

    /**
     * 准销证号
     */
    private String zxzh;

    /**
     * ems自动推送状态（0:失败，1：成功）
     */
    private String emstszt;

    /**
     * 解除原因
     */
    private String jcyy;

    /**
     * 是否完全开发(0-否，1-是)
     */
    private String sfwqkf;

    /**
     * 更正登记类型代码
     */
    private String gzdjlxdm;

    /**
     * 更正主体
     */
    private String gzzt;

    /**
     * 更正依据
     */
    private String gzyj;

    /**
     * 更正内容
     */
    private String gznr;

    /**
     * 申请材料提交方式
     */
    private String sqcltjfs;

    /**
     * 项目子编号
     */
    private String xmzbh;

    /**
     * 水电气操作人
     */
    private String sdqczr;

    /**
     * 不处理原因
     */
    private String bclyy;

    /**
     * 违约责任
     */
    private String wyzr;

    /**
     * 监证机关
     */
    private String jzjg;

    /**
     * 是否线上缴税
     */
    private String sfxsjs;

    /**
     * 查询目的（gx_yy_zd_type字典表CXMD）
     */
    private String cxmd;

    /**
     * 是否自动创建 1：是，0：否
     */
    private String sfzdcj;

    /**
     * 是否银行直连1：是，0：否
     */
    private String sfyhzl;

    /**
     * 申请单位唯一标识(代码)
     */
    private String sqdwwybs;

    /**
     * 是否台账展示，1：是（单个、批量第一个），0：否 2转移 3抵押
     */
    private String sftzzs;

    /**
     * 缴款方式 0：不交税费1：税费同缴
     */
    private String jkfs;

    /**
     * 数据来源(1:微信 2:网页 3:APP)
     */
    private String sjly;

    /**
     * 缴费方式（1:线上缴费 2:窗口缴费)
     */
    private String jffs;

    /**
     * 是否税费托管（0否，1是)
     */
    private String sfsftg;

    /**
     * 立案文书编号
     */
    private String lawsbh;

    /**
     * 律师联系电话
     */
    private String lslxdh;

    /**
     * 律师证号
     */
    private String lszh;

    /**
     * 0未查询 1已查询 有结果 2已查询 无结果 3 查询异常
     */
    private String cxzt;

    /**
     * 查询申请人类别（gx_yy_zd_type字典表CXSQRLB）
     */
    private String cxsqrlb;

    /**
     * 查询目的手填
     */
    private String cxmdst;

    /**
     * 是否需要登簿发证 （0：否，1：是）
     */
    private String sfxydbfz;

    /**
     * 公告类型
     */
    private String gglx;

    /**
     * 发布单位
     */
    private String fbdw;

    /**
     * 登记证书形式代码（1：纸质证 2：电子证）
     */
    private String djzsxsdm;

    /**
     * 预审地区代码
     */
    private String ysdqdm;

    /**
     * 集成化办公登记回调标识
     */
    private String djhdbs;

    /**
     * 集成化办公税务回调标识
     */
    private String swhdbs;

    /**
     * 拆迁单位
     */
    private String cqdw;

    /**
     * 是否推送预审 1：是，0：否
     */
    private String sftsys;

    /**
     * 是否市县一体化流程（0：否，1：是）
     */
    private String sfsxythlc;

    /**
     * 是否线下办理（1：是，0：否）
     */
    private String sfxxbl;

    /**
     * 是否完成视频公证（1：是，0：否）
     */
    private String sfwcspgz;

    /**
     * 是否已发送税费短信（1：是，0：否）
     */
    private String sfyfssfdx;

    /**
     * 完税时间
     */
    private String wssj;
    /**
     * 核税时间
     */
    private String hssj;

    /**
     * 赠与合同约定条款
     */
    private String zyhtydtk;

    /**
     * 是否需要云签 0：否 1：是，（整个流程是否需要发起云签）
     */
    private String sfyq;
    /**
     * 智慧中枢受理编号
     */
    private String zhzsslbh;
    /**
     * 证书类型（1：生成证书，2：生成证明，3：只登簿不发证）
     */
    private String zslx;
    /**
     * 用章操作人id
     */
    private List<String> yzczrid;
    /**
     * 是否勾选我已承诺,1：是 0：否
     */
    private String sfgxwycn;
    /**
     * 是否预告 （0：是 1：否）
     */
    private String sfyg;
    /**
     * 登记费免收事项代码
     */
    private String djfmssxdm;
    /**
     * 登记费免收事项名称
     */
    private String djfmssxmc;

    /**
     * 是否带押过户
     */
    private String sfdygh;

    /**
     * 是否无还本续贷款
     */
    private String sfwhbxd;

    /**
     * 是否提供现场服务
     */
    private String sftgxcfw;

    /**
     * 扩展字段json，新增字段都以json方式放该字段里面
     */
    private String kzJson;
    /**
     * 业务小类
     */
    private String ywxl;
    /**
     * 是否整体发证(0：否，1：是)
     */
    private String sfztfz;
    /**
     * 是否跨行抵押
     */
    private String sfkhdy;
    /**
     * 查询内容
     */
    private String cxnr;
    /**
     * 查询结果要求
     */
    private String cxjgyq;
}
